import java.lang.Math;

/** 
 * An encoding of the robot's current status. An instance of this
 * class will contain the sensor readings from some location, and the
 * last movement taken to get to this location.
 * @author Matt Hoffman
 * @version 2.0
 ***/
public class Status
{
    private final int    NUM_SCANS = 360/45;

    /** Rotation taken before moving. */
    public float initialRotation;

    /** Rotation taken after moving. */
    public float finalRotation;

    /** The distance moved. */
    public float distance;
    
    /** Sensor readings every 45 degrees. */
    public int[] sensors;

    /** Minimize and normalize the rotation variables. */
    public void cleanupRotation()
    {
        initialRotation = normalizeAngle(initialRotation);
        if (initialRotation > Math.PI)
            initialRotation -= 2*Math.PI;

        finalRotation = normalizeAngle(finalRotation);
        if (finalRotation > Math.PI)
            finalRotation -= 2*Math.PI;
    }

    private float normalizeAngle(float angle)
    {
        while (angle < 0)
            angle += 2*Math.PI;
        while (angle > 2*Math.PI)
            angle -= 2*Math.PI;

        return angle;
    }

    /** Basic constructor, everything is set to 0. */
    public Status() 
    {
        distance = 0.0f;
        initialRotation = 0.0f;
        finalRotation = 0.0f;
        sensors = new int[NUM_SCANS];
    }
};
